#!/bin/bash

TST_CNT=0
ERR_CNT=0

function check () {
  let TST_CNT++
  ecode=$1
  if [ $ecode -ne 0 ]; then
    echo "ERROR: exit code $ecode"
    let ERR_CNT++
  else
    echo "PASS: exit code $ecode"
  fi
  [ $ERR_CNT -eq 0 ] || exit $ERR_CNT
}

function check_msg () {
  let TST_CNT++
  res="$1"
  exp_msg_num=1
  [ -n $2 ] && exp_msg_num=$2
  msg_num=$(echo "$res" | grep "^Body:" | wc -l)
  if [ $msg_num -ne $exp_msg_num ]; then
    echo "ERROR: number of messages ($msg_num) differs from expected: ($exp_msg_num)"
    let ERR_CNT++
  else
    echo "PASS: number of messages: ($msg_num)"
  fi
  [ $ERR_CNT -eq 0 ] || exit $ERR_CNT
}
    
QPID_DEPS=`find /usr/share/java/qpid-deps/*.jar | tr '\n' ":"`
QPID_JARS=`find /usr/share/java -name 'qpid-client*.jar' -or -name 'qpid-common*.jar' | tr '\n' ":"`
LOG4J="/usr/share/java/log4j.jar"
QPID_CLASSPATH=$QPID_DEPS$LOG4J:$QPID_JARS

QPID_JAVA_EXAMPLES=$(rpm -ql qpid-java-example | head -1)

QPID_CLASSPATH="$QPID_JAVA_EXAMPLES:$QPID_CLASSPATH"

DRAIN="java -cp $QPID_CLASSPATH -Dlog4j.configuration=example.log4j org.apache.qpid.example.Drain"
SPOUT="java -cp $QPID_CLASSPATH -Dlog4j.configuration=example.log4j org.apache.qpid.example.Spout"

while [ 1 ]; do
  $DRAIN "q1;{ create:always, node: { x-bindings:[{exchange:'amq.topic',key:'usa.#' }] }, link: {  } }"
  check $?
  $DRAIN "q2;{ create:always, node: { x-bindings:[{exchange:'amq.topic',key:'#.news' }] }, link: {  } }"
  check $?
  $DRAIN "q3;{ create:always, node: { x-bindings:[{exchange:'amq.topic',key:'#.weather' }] }, link: {  } }"
  check $?
  $DRAIN "q4;{ create:always, node: { x-bindings:[{exchange:'amq.topic',key:'europe.#' }] }, link: {  } }"
  check $?
  $SPOUT --content="usa.news" "amq.topic/usa.news;{ node: {  }, link: {  } }"
  check $?
  $SPOUT --content="usa.weather" "amq.topic/usa.weather;{ node: {  }, link: {  } }"
  check $?
  $SPOUT --content="europe.news" "amq.topic/europe.news;{ node: {  }, link: {  } }"
  check $?
  $SPOUT --content="europe.weather" "amq.topic/europe.weather;{ node: {  }, link: {  } }"
  check $?
  res=$($DRAIN "q1;{ delete:always, node: {  }, link: {  } }")
  check $?
  check_msg "$res" "2"
  res=$($DRAIN "q2;{ delete:always, node: {  }, link: {  } }")
  check $?
  check_msg "$res" "2"
  res=$($DRAIN "q3;{ delete:always, node: {  }, link: {  } }")
  check $?
  check_msg "$res" "2"
  res=$($DRAIN "q4;{ delete:always, node: {  }, link: {  } }")
  check $?
  check_msg "$res" "2"
done

#.eof
